SiUX was originally created in late 2005 at Network Image.

Here is an inevitably incomplete list of MUCH-APPRECIATED CONTRIBUTORS --
people who have submitted patches, reported bugs, added translations, helped
answer newbie questions, and generally made SiUX that much better:

* Erik Brozek <erik@brozek.name>
* Pavel Svaton <pavelsvaton1@gmail.com>
* Martin Kala <martinkala@outlook.com>
* Jan Mojzis <jan@mojzis.com>
* ...
